@@ -1,6 +1,8 @@
+from .version import __version__
 from .utils import (
     TransferProgress,
     slugify_string,
+    create_dependency_package_basename,
 )
 from .server_api import (
     ServerAPI,
@@ -101,6 +103,7 @@ from ._api import (
     get_addon_studio_settings,
     get_addon_project_settings,
     get_addon_settings,
+    get_bundle_settings,
     get_addons_studio_settings,
     get_addons_project_settings,
     get_addons_settings,
@@ -182,8 +185,11 @@ from ._api import (
 
 
 __all__ = (
+    "__version__",
+
     "TransferProgress",
     "slugify_string",
+    "create_dependency_package_basename",
 
     "ServerAPI",
 
@@ -280,6 +286,7 @@ __all__ = (
     "get_addon_studio_settings",
     "get_addon_project_settings",
     "get_addon_settings",
+    "get_bundle_settings",
     "get_addons_studio_settings",
     "get_addons_project_settings",
     "get_addons_settings",
